package com.pj.tb_enterprise;

import java.io.IOException;
import java.util.List;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;


/**
 * Controller: tb_enterprise -- 商家
 * @author qzy 
 */
@RestController
@RequestMapping("/TbEnterprise/")
public class TbEnterpriseController {

	/** 底层 Service 对象 */
	@Autowired
	TbEnterpriseService tbEnterpriseService;

	/** 增 */  
	@RequestMapping("add")
	@SaCheckPermission(TbEnterprise.PERMISSION_CODE_ADD)
	public AjaxJson add(TbEnterprise t){
		tbEnterpriseService.add(t);
		t = tbEnterpriseService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */  
	@RequestMapping("delete")
	@SaCheckPermission(TbEnterprise.PERMISSION_CODE_DEL)
	public AjaxJson delete(Long id){
		 tbEnterpriseService.delete(id);
		return AjaxJson.getSuccess();
	}
	
	/** 删 - 根据id列表 */  
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbEnterprise.PERMISSION_CODE_DEL)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class); 
		int line = SP.publicMapper.deleteByIds(TbEnterprise.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}
	
	/** 改 */  
	@RequestMapping("update")
	@SaCheckPermission(TbEnterprise.PERMISSION_CODE_EDIT)
	public AjaxJson update(TbEnterprise t){
		tbEnterpriseService.update(t);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */  
	@RequestMapping("getById")
		@SaCheckPermission(TbEnterprise.PERMISSION_CODE)
	public AjaxJson getById(Long id){
		TbEnterprise t = tbEnterpriseService.getById(id);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */  
	@RequestMapping("getList")
		@SaCheckPermission(TbEnterprise.PERMISSION_CODE)
	public AjaxJson getList() { 
		SoMap so = SoMap.getRequestSoMap();
		List<TbEnterprise> list = tbEnterpriseService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}
	
	
	
	/** 改 - 删除状态(0=禁用,1=启用) */  
	@RequestMapping("updateDeleteStatus")
	@SaCheckPermission(TbEnterprise.PERMISSION_CODE_EDIT)
	public AjaxJson updateDeleteStatus(Long id, Integer value){
		int line = SP.publicMapper.updateColumnById(TbEnterprise.TABLE_NAME, "delete_status", value, id);
		return AjaxJson.getByLine(line);
	}

	/**
	 * 数据导入接口
	 * @param file
	 * @return
	 */
	@RequestMapping("enterpriseImport")
	@ResponseBody
	public AjaxJson dataImport(@RequestParam("file")MultipartFile file){
		try {
			String importData = tbEnterpriseService.importData(file);
			AjaxJson.getSuccess(importData);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		return AjaxJson.getError();
	}

	/**
	 * 导出
	 * @param keyword
	 * @return
	 */
	@RequestMapping("enterpriseOutport")
	@ResponseBody
	public AjaxJson dataOutport(@RequestParam(value = "keyword",required = false) String keyword){
		try {
			String importData = tbEnterpriseService.outportExcel(keyword);
			AjaxJson.getSuccess(importData);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		return AjaxJson.getError();
	}
	

	
	
	

}
